# Touch response

The `touch_response` plug-in allows you to work with touch responses (or mouse clicks) in an easy way, by dividing the display into rows and columns. Each response is encoded by a single number, which corresponds to the position counting from left-to-right and top-down. For example, if you have specified 2 columns and 3 rows, the display is divided into the following response regions:

	1	2
	3	4
	5	6

Similarly, if you have specified 4 columns and 1 row, the display is sliced horizontally into the following response regions:

	1	2	3	4
